import * as Messages from "/services/messages/messages.js";

let roundModel;

export function getRoundModel() {
  if (roundModel == null) {
    roundModel = new RoundModel();
  }
  return roundModel;
}

class RoundModel {
  constructor() {}

  async getRound(id) {
    if (this.rounds == null) await this.refreshRounds();
    let roundToGet;
    this.rounds.forEach((round) => {
      if (round.ID == id) roundToGet = round;
    });
    return roundToGet;
  }

  async getRounds() {
    if (this.rounds == null) {
      try {
        const response = await fetch("/api/Round/", {
          method: "GET",
          headers: new Headers({
            "XSRF-Token": this.current_user.xsrftoken,
          }),
        });
        if (response.status !== 200) {
          throw new Error(
            `Rounds could not be fetched (status ${response.status})`
          );
        }
        this.rounds = await response.json();
      } catch (e) {
        Messages.Show("is-warning", e.message);
        console.error(e);
      }
    }
    return this.rounds;
  }

  async saveRound(method, ID, ElectionID, Date, Round) {
    try {
        const response = await fetch(
            "/api/Round/" + ID,
            {
              method: method,
              headers: new Headers({
                "XSRF-Token": this.current_user.xsrftoken,
              }),
              body: JSON.stringify({
                ID: ID,
                ElectionID: ElectionID,
                Date: Date,
                Round: Round,
              }),
            }
          );
      if (response.status !== 200) {
        throw new Error(
          `Round could not be updated or created (status ${response.status})`
        );
      }
      this.refreshRounds();
      return await response.json();
    } catch (e) {
      Messages.Show("is-warning", e.message);
      console.error(e);
      return;
    }
  }

  async deleteRound(ID) {
    try {
      const response = await fetch("/api/Round/" + ID, {
        method: "delete",
        headers: new Headers({
          "XSRF-Token": this.current_user.xsrftoken,
        }),
      });
      if (response.status !== 200) {
        throw new Error(
          `Round could not be deleted (status ${response.status})`
        );
      }
    } catch (e) {
      Messages.Show("is-warning", e.message);
      console.error(e);
    }
    this.refreshRounds();
  }

  async refreshRounds() {
    this.rounds = null;
    await this.getRounds();
  }
}
